{% extends "base.html" %}
{% set active_page = 'about' %}

{% block title %}About{% endblock %}

{% block body %}

<p><strong><code>API</code></strong> <br/>
    You can submit your query to the system and take responses. Query should
    have the following format: <br/>
    <code>{{ request.url_root
        }}data?station=STATION_NAME&template=TEMPLATE_NAME</code> <br/>
    Where STATION_NAME can be retrieved issuing the following request:</p>
<p><code>Get station name</code>: <a href="{{ request.url_root }}Stations"
                                     target="_blank">{{ request.url_root
    }}Stations</a>
</p>

<p>Template name can be retrieved issuing the following request:</p>
<p><code>Get template name</code>: <a href="{{ request.url_root }}templates"
                                      target="_blank">{{ request.url_root
    }}templates</a>
</p>

{% endblock %}
