{% extends "base.html" %}

{% set active_page = "home" %}

{% block title %}Home{% endblock %}

{% block body %}
<div class="container">
    <div class="row">
        <div class="col-xs-12 col-md-6 dash-component">
            <img style="height: 70px;display:inline-block; vertical-align:middle;"
                 src="{{ url_for('static', filename='img/wur.png') }}" alt=""/>
            <h2 style="display:inline-block;" class="text-justify">
                <a class="dash-doc-link"
                   href="https://www.wur.nl/en/Expertise-Services/Chair-groups/Social-Sciences/Information-Technology-Group.htm"
                   target="_blank"> Wageningen INF Group
                </a>
            </h2>

            <p class="text-justify">
                Our mission is to contribute to the state-of-the-art of smart
                systems and system of systems engineering
                to support innovations in the life sciences application domains.
                Hereby, we focus on software
                engineering, knowledge engineering and socio-technical systems
                engineering.
            </p>
        </div>

        <div class="col-xs-12 col-md-6 dash-component">
            <img style="height: 40px;display:inline-block; vertical-align:middle;"
                 src="{{ url_for('static', filename='img/eco.png') }}" alt=""/>
            <h2 style="display:inline-block;" class="text-justify">
                <a class="dash-doc-link"
                   href="http://eco.logismi.co"
                   target="_blank"> ecologismico
                </a>
            </h2>
            <p class="text-justify">
                Ecologismico is a neologism from the Greek words ecology and
                logismico (the modern Greek word for
                software), that glues together logos (stands for reasoning in
                ancient Greek) to define the study of
                natural systems language and the research of intelligent
                software systems for the environment.
                <b>Software Engineering for the Environment</b> is a research
                group (aka "collaboratory") of the <a
                    href="http://www.intersys-lab.org" target="_blank">Internetworked
                Systems Lab</a> of the <a
                    href="http://www.ee.duth.gr/el/" target="_blank">Electrical
                and Computer Engineering Department</a>
                at Democritus University of Thrace.
            </p>
        </div>
    </div>
</div>


{% endblock %}