<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="EDAM">
    <meta name="keywords" content="EDAM,SOS,OGC">
    <meta name="author" content="Ioannis Athanasiadis">
    <meta name="author" content="Argyrios Samourkasidis">
    {% block head %}{% endblock %}
    <title>{% block title %}{% endblock %}</title>

    <!-- Bootstrap core CSS -->
    <link href="{{ url_for('static', filename='css/bootstrap.css') }}"
          rel="stylesheet" media="screen">
    <link href="{{ url_for('static', filename='css/app.css') }}"
          rel="stylesheet" media="screen">
    <link rel="shortcut icon"
          href="{{ url_for('static', filename='img/favicon.ico') }}"/>

    <script src="{{ url_for('static', filename='js/plotly.js') }}"></script>
    <script src="{{ url_for('static', filename='js/d3.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/jquery-3.5.1.min.js') }}"></script>
    <link href="{{ url_for('static', filename='css/select2.min.css') }}"
          rel="stylesheet"/>
    <script src="{{ url_for('static', filename='js/select2.min.js') }}"></script>
</head>

<body>
{% set navigation_bar = [
('/maps/', 'maps', 'Maps'),
('/about/', 'about', 'API'),
('/home/', 'home', 'Home'),
('/graphs', 'graphs', 'Graphs')
] -%}
{% set active_page = active_page|default('maps') %}

<div class="navbar navbar-static-top">
    <div class="navbar-inner">
        <div class="container">
            <h1 class="text-white brand navbar-header navbar-brand"><a href={{
                                                                       url_for('mapview')
                }}> EDAM </a></h1>
            <ul class="nav nav-pills inline-navbar">
                {% for href, id, caption in navigation_bar %}
                <li
                        {% if id== active_page %} class="active" {% endif %}><a
                        href="{{ href|e }}">{{ caption|e }}</a>
                </li>
                {% endfor %}
            </ul>
        </div>
    </div>
</div>

<div class="container">
    {% block body %}{% endblock %}
</div>
<script src="{{ url_for('static', filename='js/plot.js') }}"></script>
<script src="{{ url_for('static', filename='bootstrap/js/bootstrap.min.js') }}"></script>
<script src="{{ url_for('static', filename='js/custom.js') }}"></script>
</body>
</html>
